#
# spec file for package xscreensaver
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xscreensaver
Version:        6.08
Release:        2.2
Summary:        A screen saver and locker for the X Window System
License:        BSD-3-Clause AND GPL-2.0-or-later
Group:          Amusements/Toys/Screensavers
URL:            https://www.jwz.org/xscreensaver
Source:         https://www.jwz.org/xscreensaver/%{name}-%{version}.tar.gz
Source1:        xscreensaver.pamd
Source2:        xscreensaver-data.list
Source3:        xscreensaver-data-extra.list
#
Source4:        xscreensaver-desktops-generate.sh
# Do not show some rpmlint warnings.
Source99:       xscreensaver-rpmlintrc
#
Patch5:         xscreensaver-background.patch
Patch20:        xscreensaver-mansuffix.patch
Patch21:        xscreensaver-default-screensaver.patch
Patch29:        xscreensaver-ignore-no-pwent-password.patch
Patch32:        xscreensaver-fireworkx-man.patch
# PATCH-FIX-OPENSUSE xscreensaver-webcollage-dictpath.patch seife+obs@b1-systems.com -- Add /var/lib/dict/words to search path for word dictionaries.
Patch42:        xscreensaver-webcollage-dictpath.patch
# PATCH-FEATURE-OPENSUSE xscreensaver-disable-upgrade-nagging.patch boo#890595 gber@opensuse.org -- Disable nagging messages about upgrading to a newer version.
Patch43:        xscreensaver-disable-upgrade-nagging-message.patch
# PATCH-FEATURE-OPENSUSE xscreensaver-bug-reports.patch bnc890595 sbrabec@suse.cz -- Ask reporters to upgrade before reporting bugs.
Patch45:        xscreensaver-bug-reports.patch
# PATCH-FIX-OPENSUSE xscreensaver-unrecognized-opts.patch sbrabec@suse.com -- Ignore selected unbrecognized options generated by %%configure.
Patch46:        xscreensaver-unrecognized-opts.patch
BuildRequires:  automake
BuildRequires:  bc
BuildRequires:  gdmflexiserver
BuildRequires:  gtkdoc
BuildRequires:  intltool
BuildRequires:  libgle-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libxslt-tools
BuildRequires:  pam-devel
BuildRequires:  perl-XML-Parser
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
#BuildRequires:  pkgconfig(atk)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
#BuildRequires:  pkgconfig(gdk-pixbuf-xlib-2.0)
#BuildRequires:  pkgconfig(gdk-x11-2.0)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xft)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xmu)
BuildRequires:  pkgconfig(xpm)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xt)
BuildRequires:  pkgconfig(xxf86vm)
#
Requires:       %{name}-data
Requires:       /sbin/unix2_chkpwd
Requires:       desktop-data
Recommends:     %{name}-lang = %{version}
#
Suggests:       %{name}-data-extra
#
Provides:       xscreensaver-gnome = %{version}
Provides:       xscrns = %{version}
Obsoletes:      xscreensaver-gnome < %{version}
Obsoletes:      xscrns < %{version}

%description
The xscreensaver program waits until the keyboard and mouse have
been idle for a period of time, and then runs a graphics demo
chosen at random. It turns off as soon as there is any mouse or
keyboard activity. It can also lock the screen immediately, after a
longer idle period, or on demand.

The xscreensaver package consists of two parts: the screensaver and
the "driver" or "daemon", which detects idleness and does locking,
and the many graphics demos that are launched by xscreensaver.

Any X program that can draw on the root window can be used with
xscreensaver, regardless of how that program is written, what
language it is written in, or what libraries it uses. The
xscreensaver daemon takes care of detecting when the user is idle,
locking, and checking passwords and all the other book-keeping. All
the other programs need to do is draw.

The benefit that xscreensaver has over the combination of the xlock
and xautolock programs is the ease with which new graphic hacks can
be installed. You do not need to recompile (or even re-run) the
xscreensaver program to add a new display mode, you just change a
config file.

%package data
Summary:        Selection of screensavers from xscreensaver
Group:          Amusements/Toys/Screensavers
Recommends:     %{name}-lang = %{version}

%description data
The xscreensaver program waits until the keyboard and mouse have
been idle for a period of time, and then runs a graphics demo
chosen at random. It turns off as soon as there is any mouse or
keyboard activity. It can also lock the screen immediately, after a
longer idle period, or on demand.

This packages contains a selection of graphics demos.

%package data-extra
Summary:        Selection of screensavers from xscreensaver
Group:          Amusements/Toys/Screensavers
Recommends:     %{name}-data
Recommends:     %{name}-lang = %{version}

%description data-extra
The xscreensaver program waits until the keyboard and mouse have
been idle for a period of time, and then runs a graphics demo
chosen at random. It turns off as soon as there is any mouse or
keyboard activity. It can also lock the screen immediately, after a
longer idle period, or on demand.

This packages contains additional graphics demos.

%lang_package

%prep
%autosetup -p1
# KDE, GNOME and MATE have there own screensavers:
#echo 'NotShowIn=KDE;GNOME;MATE;' >> driver/screensaver-properties.desktop.in
cp -f %{SOURCE4} xscreensaver-desktops-generate
chmod a+x xscreensaver-desktops-generate

# /etc directories are hardcoded everywhere
# Move xscreensaver's PAM files.
%if 0%{?suse_version} > 1500
sed -i 's|/etc/pam.d|%{_pam_vendordir}|g' configure driver/passwd-pam.c xscreensaver.spec configure.ac driver/xscreensaver.man
sed -i 's|= /etc|= /usr/lib|g' driver/Makefile.in
%endif

%build
# Fix man pages header:
find hacks -name '*.man' -print0 | xargs -0 sed -ie 's/TH XScreenSaver 1/TH XScreenSaver 6/'
# Modify hack list to fit our needs:
sed -re '
  s/^([[:space:]]*(rorschach|greynetic|noseguy|deco|moire|spiral|laser|sierpinski|flag|sphere|mountain|triangle|worm|xlyap|cynosure|bsod|t3d|wander"Wander|critical|phosphor|blaster|nerverot|"SpeedMine"|poluominoes|fluidballs|barcode|bubbles))/-\1/;
  s/^-([[:space:]]*(juggle))/\1/;
  s/^@GL_KLUDGE@([[:space:]]*GL:[[:space:]]*(sproingies|"Molecule \(lumpy\)"|circuit|atunnel|glmatrix|stairs|pulsar|starwars|"GLText|boxed|"GLForestFire"|sballs|cubenetic|queens|endgame))/-\1/;
  s/^-([[:space:]]*GL:[[:space:]]*(fireflies))/\1/;
  /.*vidwhacker -stdin -stdout/D;
  ' driver/XScreenSaver.ad.in > driver/XScreenSaver.ad.in.tmp && mv -f driver/XScreenSaver.ad.in.tmp driver/XScreenSaver.ad.in
intltoolize --copy --force
chmod +x install-sh
cp /usr/share/gettext/config.rpath .
autoreconf -fi
# Regarding options checking: %%configure includes --disable-dependency-tracking, which causes fatal error.
# Please try to comment out during the upgrade. You should see exactly this single error.
export enable_option_checking=no
sed -i "s|@install_sh@|../install-sh -c|" po/Makefile.in.in
#lie to configure so the default C standard is used
export ac_cv_gcc_accepts_std=no
# Disable direct PAM use and shadow (both needs suid).
bash -x %configure \
  --with-configdir=%{_sysconfdir}/xscreensaver       \
  --with-app-defaults=%{_datadir}/X11/app-defaults   \
  --without-kerberos                                 \
  --with-gl                                          \
  --with-gle                                         \
  --with-pixbuf                                      \
  --with-jpeg                                        \
  --with-xshm-ext                                    \
  --with-xdbe-ext                                    \
  --with-pam                                         \
  --enable-pam-account                               \
  --without-shadow                                   \
  --with-login-manager=%{_bindir}/gdmflexiserver     \
  --with-image-directory=%{_datadir}/wallpapers      \
  --enable-locking                                   \
  --with-login-manager
%make_build all

%install
rm -f hacks/config/vidwhacker.xml
mkdir -p %{buildroot}/tmp/bin/

# Another hack for pam
%if 0%{?suse_version} > 1500
mkdir -p %{buildroot}%{_pam_vendordir}
%endif

make install_prefix=%{buildroot} \
  KDEDIR=/tmp                    \
  DESTDIR=%{buildroot}           \
  datadir=%{_datadir}            \
  install
rm -r %{buildroot}/tmp/
#
# Remove obsolete SUID bit.
chmod 0755 %{buildroot}%{_bindir}/xscreensaver
#
# PAM config.
%if 0%{?suse_version} > 1500
mkdir -p %{buildroot}%{_pam_vendordir}
install -Dm 0644 %{SOURCE1} %{buildroot}%{_pam_vendordir}/xscreensaver
%else
install -Dm 0644 %{SOURCE1} %{buildroot}%{_sysconfdir}/pam.d/xscreensaver
%endif
#
# Language files.
%find_lang %{name}
#
# Desktop files.
#%%suse_update_desktop_file -G "Screensaver properties" xscreensaver-properties DesktopSettings
#
# Generate .desktop files for mate-screensaver usage.
mkdir -p %{buildroot}%{_datadir}/applications/screensavers/
./xscreensaver-desktops-generate %{buildroot}%{_sysconfdir}/xscreensaver/ %{buildroot}%{_datadir}/applications/screensavers/
# Remove duplicate of a file from mate-screensaver.
rm -f %{buildroot}%{_datadir}/applications/screensavers/popsquares.desktop
#
# List files for screensavers in data and data-extra subpackages.
rm -f %{name}-data.lst %{name}-data-extra.lst
for hack in $(grep -v '#' %{SOURCE2}); do
    [ -f %{buildroot}%{_mandir}/man6/$hack.6* ] && echo "%doc %{_mandir}/man6/$hack.6*" >> %{name}-data.lst
    [ -f %{buildroot}%{_sysconfdir}/xscreensaver/$hack.xml ] && echo "%config %{_sysconfdir}/xscreensaver/$hack.xml" >> %{name}-data.lst
    [ -f %{buildroot}%{_datadir}/applications/screensavers/$hack.desktop ] && echo "%{_datadir}/applications/screensavers/$hack.desktop" >> %{name}-data.lst
    echo "%{_libexecdir}/xscreensaver/$hack" >> %{name}-data.lst
done
for hack in $(grep -v '#' %{SOURCE3}); do
    [ -f %{buildroot}%{_mandir}/man6/$hack.6* ] && echo "%doc %{_mandir}/man6/$hack.6*" >> %{name}-data-extra.lst
    [ -f %{buildroot}%{_sysconfdir}/xscreensaver/$hack.xml ] && echo "%config %{_sysconfdir}/xscreensaver/$hack.xml" >> %{name}-data-extra.lst
    [ -f %{buildroot}%{_datadir}/applications/screensavers/$hack.desktop ] && echo "%{_datadir}/applications/screensavers/$hack.desktop" >> %{name}-data-extra.lst
    echo "%{_libexecdir}/xscreensaver/$hack" >> %{name}-data-extra.lst
done

%if 0%{?suse_version} > 1500
%pre
# Prepare for migration to /usr/lib; save any old .rpmsave
for i in pam.d/xscreensaver ; do
     test -f %{_sysconfdir}/${i}.rpmsave && mv -v %{_sysconfdir}/${i}.rpmsave %{_sysconfdir}/${i}.rpmsave.old ||:
done

%posttrans
# Migration to /usr/lib, restore just created .rpmsave
for i in pam.d/xscreensaver ; do
     test -f %{_sysconfdir}/${i}.rpmsave && mv -v %{_sysconfdir}/${i}.rpmsave %{_sysconfdir}/${i} ||:
done
%endif

%files
%doc README
%{_bindir}/xscreensaver
%{_bindir}/xscreensaver-command
%{_bindir}/xscreensaver-demo
%{_bindir}/xscreensaver-settings
%{_datadir}/applications/xscreensaver.desktop
%{_datadir}/applications/xscreensaver-settings.desktop
%{_datadir}/fonts/xscreensaver
%{_datadir}/pixmaps/xscreensaver.png
%dir %{_datadir}/xscreensaver
#%%{_datadir}/xscreensaver/ui
%{_datadir}/xscreensaver/xscreensaver.service
%{_libexecdir}/xscreensaver/xscreensaver-auth
%{_libexecdir}/xscreensaver/xscreensaver-gfx
%{_libexecdir}/xscreensaver/xscreensaver-gl-visual
%{_libexecdir}/xscreensaver/xscreensaver-systemd
%dir %{_datadir}/X11/app-defaults
%{_datadir}/X11/app-defaults/XScreenSaver
%{_mandir}/man1/xscreensaver.*
%{_mandir}/man1/xscreensaver-command.*
%{_mandir}/man1/xscreensaver-demo.*
%{_mandir}/man1/xscreensaver-settings.*
%{_mandir}/man6/xscreensaver-auth.*
%{_mandir}/man6/xscreensaver-gfx.*
%{_mandir}/man6/xscreensaver-gl-visual.*
%{_mandir}/man6/xscreensaver-systemd.*
%if 0%{?suse_version} > 1500
%{_pam_vendordir}/xscreensaver
%else
%config %{_sysconfdir}/pam.d/xscreensaver
%endif
%dir %{_sysconfdir}/xscreensaver/
%config %{_sysconfdir}/xscreensaver/README

%files lang -f %{name}.lang

%files data -f %{name}-data.lst
%dir %{_libexecdir}/xscreensaver/
%dir %{_sysconfdir}/xscreensaver/
%dir %{_datadir}/applications/screensavers/

%files data-extra -f %{name}-data-extra.lst
%dir %{_libexecdir}/xscreensaver/
%{_libexecdir}/xscreensaver/xscreensaver-getimage
%{_libexecdir}/xscreensaver/xscreensaver-getimage-file
%{_libexecdir}/xscreensaver/xscreensaver-getimage-video
%{_libexecdir}/xscreensaver/xscreensaver-text
%{_libexecdir}/xscreensaver/mapscroller.pl
%dir %{_sysconfdir}/xscreensaver/
%dir %{_datadir}/applications/screensavers/
# Screensavers using those utilities are in this package.
%{_mandir}/man6/xscreensaver-getimage.*
%{_mandir}/man6/xscreensaver-getimage-file.*
%{_mandir}/man6/xscreensaver-getimage-video.*
%{_mandir}/man6/xscreensaver-text.*

%changelog
* Wed Oct 11 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 6.08:
  * fixes for other platforms
* Sun Oct  1 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 6.07:
  * New hacks, droste, skulloop, papercube and cubocteversion
  * xscreensaver-settings was sometimes turning off the DPMS
    checkbox
  * Log pid of caller of deactivate command, to give a hint about
    who is preventing the screen from blanking
  * Updates to sphereeversion.
  * Added some new map sources to mapscroller.
  * Various other minor bug fixes.
- leave a nice notice for a very angry upstream developer in
  xscreensaver-disable-upgrade-nagging-message.patch (bsc#1217318)
- drop xscreensaver-bsc1204744.patch, included upstream
* Thu Mar 16 2023 Michal Suchanek <msuchanek@suse.com>
- Drop obsolete patch (bsc#1203594).
  - xscreensaver-slideshow-dri-detect.patch
- Use autosetup
* Mon Mar  6 2023 Jason Sikes <jsikes@suse.com>
- Added spec file changes to handle hard-coded PAM directories.
  * bsc#1204744
* Thu Feb 23 2023 Jason Sikes <jsikes@suse.com>
- Added fix for configuration reading
  * Added xscreensaver-bsc1204744.patch
  * bsc#1204744
  * Patch provided by Jaroslav Jindrak
* Wed Jan  4 2023 Stefan Schubert <schubi@suse.com>
- Migration of PAM settings to /usr/lib/pam.d.
* Tue Dec 13 2022 Andreas Stieger <andreas.stieger@gmx.de>
- update to 6.06:
  * New hack hextrail
  * marbling works again
  * Adjust old hacks for higher resolution displays
  * X11: More robust desktop image grabbing.
  * X11: Various improvements to xscreensaver-settings
  * X11: Supports "Lock" messages from systemd, e.g. when
    logind.conf has "HandleLidSwitch=lock" instead of "suspend".
  * Retired thornbird, which is redundant with discrete.
- drop xscreensaver-gtk3.patch, upstream
* Mon Dec 12 2022 Andreas Stieger <andreas.stieger@gmx.de>
- fix removal of nagging message boo#1206345
* Tue Oct 11 2022 Stanislav Brabec <sbrabec@suse.com>
- update to version 6.05.1:
  * Cope with dumb DPMS settings that existed pre-startup.
  * Silence new Perl warnings from xscreensaver-getimage-file.
  * Fix sonar pthreads crash on recent Pi systems.
  * Removed dependence on gdk-pixbuf-xlib-2.0.
  * GTK 3 is now required.
  * New hacks, nakagin and chompytower.
  * Settings dialog shows diagnostics for bad image folders and
    feeds.
  * URLs for imageDirectory can now point at archive.org
    collections.
  * Sliders for various "Speed" preferences are easier to use.
  * Settings dialog shows saver description below embedded preview.
  * Better behavior when zero monitors are attached.
  * Improvements to inhibiting blanking while videos are playing:
    No longer necessary to hack GNOME and KDE to get them to not
    usurp the org.freedesktop.ScreenSaver endpoint.
  * unicrud displays character names.
  * Updated webcollage.
- Ignore selected unbrecognized options generated by %%%%configure
  (xscreensaver-unrecognized-opts.patch).
- Properly find gtk3 directories (xscreensaver-gtk3.patch).
- Refresh xscreensaver-bug-reports.patch,
  xscreensaver-default-screensaver.patch,
  xscreensaver-fireworkx-man.patch.
* Fri May 20 2022 Giacomo Comes <gcomes.obs@gmail.com>
- Add option --with-app-defaults to configure
  * fix boo#1199742
* Mon Apr  4 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build with autoconf 2.71: call sed only after autoreconf.
  autoconf 2.71 internally calls intltoolize again, overwriting
  po/Makefile.in.in.
* Sun Apr  3 2022 Stephan Kulow <coolo@suse.com>
- Copy config.rpath from gettext to have autoreconf work for autoconf
  2.71
* Mon Feb 28 2022 Andreas Stieger <andreas.stieger@gmx.de>
- update to 6.03:
  * New hacks squirtorus, mapscroller
  * sphereeversion now has corrugation-mode, and can evert the Earth
  * glplanet is higher resolution, and displays time zones
  * glslideshow displays relative pathnames again
  * X11: fixed sonar failing to ping on some Linux systems
  * X11: Touch-screens work
  * X11: Hold down Backspace to clear the whole password field (bsc#1196593)
- drop xscreensaver-6.02-marbling-std-c.patch
* Sat Jan  1 2022 Michal Suchanek <msuchanek@suse.com>
- Reenable PAM (boo#1194058).
* Tue Dec 21 2021 Stanislav Brabec <sbrabec@suse.com>
- Do not own /usr/share/fonts. It belongs to filesystem.
* Sat Nov 13 2021 Stanislav Brabec <sbrabec@suse.com>
- Update to version 6.02:
  * New hacks, `marbling' and `binaryhorizon'.
  * `atlantis' behaviors are more random and lifelike.
  * `headroom' is now Mask Headroom.
  * `fontglide' skips fonts that can't display ASCII.
  * Use asterisks in the password dialog if the system fonts don't
    have bullets in them.
  * "Disable Screen Saver" was behaving like "Blank Screen Only".
- Fix compilation with older versions of gcc and on aarch64
  (xscreensaver-6.02-marbling-std-c.patch).
* Mon Aug 30 2021 Stanislav Brabec <sbrabec@suse.com>
- Update to version 6.01:
  * Major refactor of the `xscreensaver' daemon for improved
    security, dividing it into three programs: `xscreensaver',
    `xscreensaver-gfx' and `xscreensaver-auth'.
  * Renamed `xscreensaver-demo' to `xscreensaver-settings'.
  * Unlock dialog has user-selectable color schemes.
  * Everything uses XFreeType for fonts now.
  * Install a few custom fonts needed by some savers.
  * Properly disable the server's built-in screen saver.
  * The passwdTimeout option was being ignored.
  * The display of the unlock thermometer was weird.
  * Fixed password entry on old-school multi-screen setups (:0.1).
  * Worked around a KDE 5 compositor bug that caused the desktop
    to momentarily become visible when cycling.
  * Fixed possible high CPU usage in `xscreensaver-systemd'.
  * Fixed some spurious warnings in `xscreensaver-text'.
  * Warn when Wayland is in use, since it makes both screen saving
    and locking impossible.
  * Dropped support for systems older than X11R7 (2009).
  * Fading works on systems without gamma (e.g. Raspberry Pi).
  * Use EGL instead of GLX when available.
  * `xscreensaver-systemd' now detects when a video player has
    inhibited screen blanking and then exits without uninhibiting.
  * Improved GLSL and GLES3 support: Phong shading in `etruscanvenus',
    `hypertorus', `klein', `projectiveplane',`romanboy' and
    `sphereeversion'.
  * Updates to `cubicgrid'.
- Refresh xscreensaver-disable-upgrade-nagging-message.patch.
- Use default libexecdir.
* Wed Feb 24 2021 Stanislav Brabec <sbrabec@suse.com>
- Update to version 5.45:
  * New hacks, covid19, headroom, sphereeversion and beats.
  * Shader updates to hypertorus.
  * No more image-loading pause in glslideshow.
  * BSOD supports GNOME.
  * Image loaders support SVG.
  * xscreensaver-systemd now allows video players to request that
    the screen not blank.
  * -log implies -verbose -no-capture-stderr.
  * Glade -> GtkBuilder.
  * Various bug fixes.
* Sat Mar 28 2020 Andreas Stieger <andreas.stieger@gmx.de>
- update to 5.44:
  * New hacks, gibson, etruscanvenus and scooter
  * BSOD supports Tivo and Nintendo
  * New color options in romanboy, projectiveplane, hypertorus and
    klein
  * Performance tweaks for eruption, fireworkx, halftone, halo,
    moire2, rd-bomb
  * X11: Always use $HOME/.xscreensaver, not getpwuid's directory
  * Various bug fixes
* Tue Mar  3 2020 sbrabec@suse.com
- Update to version 5.43:
  * New hacks GravityWell, DeepStars, handsy.
  * GLPlanet now supports the Mercator projection.
  * Bouncing Cow has mathematically ideal cows.
  * Foggy toasters.
  * Unknown Pleasures can now use an image file as a clip mask.
  * Updated webcollage for recent changes.
  * Added some sample unlock dialog color schemes to the .ad file.
  * On systemd systems, closing your laptop lid might actually lock
    your screen now, maybe (boo#1101393).
  * sonar can ping without being setuid by using setcap.
  * Those new font-loading fallback heuristics work again. Oops.
  * Fixed `noof' from displaying minimalistically.
  * Rewrote `unknownpleasures' to be faster, and a true waterfall
    graph.
  * If the xscreensaver daemon is setuid, then we can implore the
    kernel's out-of-memory killer to pretty please not unlock the
    screen.
  * Fix several bugs (fixes BadWindow error bsc#1165170).
- Drop xscreensaver-lock-after-fade.patch. Upstream has a different
  fix (boo#1101393).
- Refresh xscreensaver-default-screensaver.patch.
- Update xscreensaver-data-extra.list and xscreensaver-data.list.
* Wed Jun 26 2019 Stefan Dirsch <sndirsch@suse.com>
- no longer require Xxf86misc extension, which is no longer supported
  with xorgproto 2019.1; it has been removed from Xserver years ago
  anyway
* Thu Nov 15 2018 sbrabec@suse.com
- Update to version 5.40:
  * New hacks filmleader vfeedback glitchpeg, razzledazzle,
    peepers, crumbler, maze3d and esper.
  * webcollagenow works with ImageMagick.
  * Improvemenrs of GLPlanet, DymaxionMap, Tessellimage, XAnalogTV.
  * More heuristics for using RSS feeds as image sources.
  * Built-in image assets are now PNG instead of XPM or XBM.
  * Better font-loading fallback.
- Refresh xscreensaver-disable-upgrade-nagging-message.patch.
- Remove obsolete --with-xpm.
- When we are disabling nagging message then reports sent be to us
  (bnc#890595, xscreensaver-bug-reports.patch).
- Lock after completing fade
  (boo#1101393, xscreensaver-lock-after-fade.patch).
* Thu Mar 15 2018 crrodriguez@opensuse.org
- remove xorg-x11-devel from buildrequires, replaced
  by extensive list of pkgconfig() style deps,
* Wed Nov 22 2017 mgorse@suse.com
- Remove libgnome-devel from BuildRequires; appears to be unused
  (boo#1067727).
* Wed Nov  8 2017 kukuk@suse.de
- Fix requires for /sbin/unix2_chkpwd [bsc#1067103]
* Wed Jul 26 2017 sbrabec@suse.com
- Update to version 5.37:
  * New hack vigilance.
  * Updates of bsod and webcollage.
  * Bug fixes.
- Added vigilance hack to xscreensaver-data-extra.list.
- Split -lang package with translations.
* Mon Feb 27 2017 sfalken@opensuse.org
- Added new hacks to xscreensaver-data-extra.list
- Rebased patches:
  * xscreensaver-disable-upgrade-nagging-message.patch
  * xscreensaver-slideshow-dri-detect.patch
- Update to 5.36:
  * New hacks, `discoball', `cubetwist', `cubestack', `splodesic'
    and `hexstrut'.
  * OSX: loading image files works in `dymaxionmap', `glplanet',
    `lavalite', `pulsar', `gleidescope' and `extrusion'.
  * Several new programs in `m6502'.
  * `rotzoomer -mode circle'.
  * Better titles in `photopile'.
- Update to 5.35:
  * New hacks, `dymaxionmap', `unicrud', `energystream', `raverhoop'
    and `hydrostat'.
  * Added Windows 10 to `bsod'.
  * X11: ignore WM_USER_TIME property changes with days-old timestamps.
    Thanks, KDE.
  * MacOS, iOS: Better fonts in `BSOD' and `memscroller'.
  * MacOS 10.8 or later and iOS 6.0 or later are now required, since
    Xcode 6 can no longer build executables that work on older OSes.
  * Many, many Android improvements.
  * iOS: Fixed rotation to work with the new iOS 8+ API.
  * X11: `pong' is now playable.
* Thu Nov  5 2015 sbrabec@suse.com
- Update to version 5.34:
  * Fixed a crash when hot-swapping monitors while locked
    (bsc#952062, CVE-2015-8025).
  * Fixed some incorrect output from `xscreensaver-command -watch'.
* Mon Oct 12 2015 sor.alexei@meowr.ru
- Generate screensavers .desktop files for mate-screensaver with
  xscreensaver-desktops-generate.sh.
- Add MATE into a NotShowIn list.
- Make xscreensaver-data-extra recommend xscreensaver-data.
- Spec cleanup.
* Thu Sep 10 2015 mpluskal@suse.com
- Update to 5.33
  * New hacks, splitflap and romanboy.
  * Better detection of user activity on modern GNOME systems.
  * Sonar now does asynchronous host name resolution.
  * Improved Unicode support.
  * Updated webcollage for recent changes.
  * Various minor fixes.
* Wed Mar 11 2015 dimstar@opensuse.org
- BuildRequire gdmflexiserver instead of gdm: there is no need to
  pull in half of the GNOME Stack here.
* Fri Jan  2 2015 chris@computersalat.de
- update to 5.32
  * Fixed some X11 compilation problems.
  * Fixed display size and shake gestures on iOS.
- 5.31    15-Nov-2014
  * New hacks, geodesicgears, binaryring and cityflow.
  * UTF-8 text support (instead of only Latin1) and antialiased text
    on X11 with Xft (instead of only on OSX/iOS) in fontglide,
    noseguy, fliptext, starwars, and winduprobot. The other
    text-displaying hacks (apple2, phosphor, xmatrix, and gltext)
    also now accept UTF-8 input, though they convert it to Latin1 or
    ASCII.
  * glplanet now has both day and night maps, and a sharp terminator.
  * Fixed webcollage on OSX.
  * Fixed a transparency glitch in winduprobot.
  * lockward works on iOS.
  * Text and image loading work on OSX 10.10.
  * Rotation works properly on iOS 8.
  * Added a search field on iOS.
  * Preliminary, unfinished support for Android.
- 5.30    11-Sep-2014
  * New hack, winduprobot.
  * Many improvements to lament, including Leviathan.
  * Fixed the normals in flyingtoasters: shading is correct now.
  * Implemented TEXTURE_GEN in GLES: flying toast is now toasted on iOS.
  * Make cel-shading sort-of work in skytentacles on iOS.
  * Fixed dragging-to-rotate on rotated iOS devices, I think.
  * Dragging has inertia now.
  * Most hacks respond to mouse-clicks, double-taps and swipes as
    meaning “do something different now”.
  * Reworked OpenGL fonts.
  * The OSX auto-update installer wasn't working. This time for sure?
  * Various minor fixes.
- rebase patches (and to be p0)
- add new savers to data-extra.list
  * binaryring
  * cityflow
  * geodesicgears
  * winduprobot
- add configure option
  * with-x-app-defaults=%%{_datadir}/X11/app-defaults
    default changed to /usr/lib/X11/app-defaults
- removed unknown configure option
  * with-icondir=%%{_datadir}/xscreensaver/pixmaps
- add rpmlintrc
  * addFilter('binary-or-shlib-calls-gethostbyname')
- some rpmlint fixes
  * obsoletes and provides
* Fri Aug 15 2014 gber@opensuse.org
- add xscreensaver-disable-upgrade-nagging-message.patch in order
  to disable nagging messages about upgrading to a newer version
  (bnc#890595)
* Wed Jun 25 2014 coolo@suse.com
- update to 5.29
  * Updated webcollage for recent changes.
  * Fixed some compilation problems and intermittent crashes.
  * New hacks, tessellimage and projectiveplane.
  * Added support for pthreads, because Dave Odell is a madman.
  * X11: Don't assume Suspend = 0 implies “No DPMS”.
  * Minor updates to boxed and klein.
  * Fixed possible crash in apple2, noseguy, xmatrix, shadebobs.
  * Fixed possible crash in OSX preferences.
  * Plugged some leaks.
* Wed Apr  9 2014 seife+obs@b1-systems.com
- de-censor xscreensaver by reenabling webcollage
- fix dictionary path for webcollage
  => xscreensaver-webcollage-dictpath.patch
* Sun Apr  6 2014 seife+obs@b1-systems.com
- update to 5.26, most important changes:
  * New hack, `geodesic'.
  * Updated `webcollage' for recent Google changes.
  * Updated `webcollage' for recent Flickr changes.
  * Added Instagram and Bing as `webcollage' image sources.
  * Updated feed-loading for recent Flickr changes.
  * More heuristics for using RSS feeds as image sources.
  * Improved Wikipedia parser.
  * Added Android to `bsod'.
  * Made `quasicrystal' work on weak graphics cards.
  * Better compression on icons, plists and XML files: smaller
    distribution and installation footprint.
  * `Phosphor' now supports amber as well as green.
  * Reverted that DEACTIVATE change. Bad idea.
  * Updated to latest autoconf.
  * Bug fixes.
* Thu Aug  1 2013 coolo@suse.com
- update to 5.22
  * New hacks, kaleidocycle, quasicrystal, unknownpleasures and hexadrop.
  * Performance improvements for interference.
  * Fixed possible crashes in apple2, maze, pacman, polyominoes, fireworkx, engine.
  * Fix for bumps in 64 bit.
  * Fixed ``Shake to Randomize''; display name of saver.
  * Fixed rotation problems with pacman, decayscreen.
  * Better dragging in fluidballs.
  * Ignore rotation in hacks that don't benefit from it.
  * Ignore DEACTIVATE messages when locked, instead of popping up the password dialog box.
  5.21	04-Feb-2013
  * Changed default text source from Twitter to Wikipedia, since Twitter now requires a login to get any feeds.
  * New version of fireworkx.
  * Minor fixes to distort, fontglide, xmatrix.
  * New MacOS crash in bsod.
  * New mode in lcdscrub.
- remove xscreensaver-stars.patch as xscreensaver is no longer used for NLD :)
* Wed Dec 26 2012 andrea@opensuse.org
- new upstream version 5.20
  * Made pipes be ridiculously less efficient, but spin.
  * Added better mouse control to rubik, cube21, crackberg, and julia.
  * Cosmetic improvements to queens and endgame.
  * sonar can now ping local subnet on DHCP.
  * Most savers now resize/rotate properly.
  * Various fixes.
  * Fixed some compilation problems.
  * Enlarged the texture image for lament.
  * XInput devices now also ignore small mouse motions.
  * Loading images via RSS feeds is much improved.
- rebased xscreensaver-default-screensaver.patch and xscreensaver-stars.patch
  to apply to new code
* Tue Sep 18 2012 coolo@suse.com
- add explicit buildrequire on pkgconfig(glu)
* Mon Jun 25 2012 coolo@suse.com
- own app-defaults directory
* Tue Feb 21 2012 coolo@suse.com
- update to 5.15
  * New hacks, hilbert, companioncube and tronbit.
  * Image-manipulating hacks can now load from RSS or Atom feeds:
    imageDirectory may contain a URL.
  * Updated webcollage for recent search engine changes.
  * phosphor and apple2 can now be run as standalone terminal
    emulator applications on MacOS.
  * photopile sped up.
  * New molecule in molecule.
  * Turned on LC_CTYPE on Linux; maybe Japanese password entry works now?
* Mon Dec 19 2011 coolo@suse.de
- adapt license (bnc#735046)
* Thu Dec  1 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Tue Aug 23 2011 coolo@novell.com
- remove those broken _service files, they are just fragile and annoying
* Sat Aug 13 2011 dmueller@suse.de
- remove libdrm-devel buildrequires
* Tue Jun  7 2011 pgajdos@novell.com
- updated to 5.14:
  * Added "Quick Power-off in Blank Only Mode" option.
  * BSOD GLaDOS.
  * Optionally enabled full-scene OpenGL antialiasing.
    Set the resource `*multiSample' to true if doing so
    doesn't kill performance with your video hardware.
  * New version of `glhanoi'.
  * Image-loading hacks that display the file name now also
    display the sub-directory (xscreensaver-getimage now
    returns relative paths under imageDirectory).
  * Passwords that contain UTF-8 non-Latin1 chars are now
    typeable.
  * Numerous minor stability fixes.
* Mon Jan 10 2011 coolo@novell.com
- remove old patches
* Mon Jan 10 2011 coolo@novell.com
- update to 5.12
  * New molecule in `molecule'.
  * `glhanoi' now supports an arbitrary number of poles.
  * Turned on "New Login" button by default.
  * Added support for XInput-style alternate input devices.
* Tue Sep  7 2010 coolo@novell.com
- update to 5.11
  * New versions of photopile, strange.
  * Fixed flicker in pipes, cubestorm, and noof.
  * Minor fixes to circuit, polyhedra, tangram, gears, pinion,
    substrate, xanalogtv.
  * Fixed some leaks in xanalogtv and apple2.
  * Better seeding of the RNG.
* Tue Jul  6 2010 guido+opensuse.org@berhoerster.name
- fixed last patch to really use DPMS
* Tue May 18 2010 guido+opensuse.org@berhoerster.name
- changed some defaults:
  + use DPMS by default
  + do not display splash screen
  + lock screen by default
  + nice to 19
* Fri Mar 26 2010 vuntz@opensuse.org
- Split screensavers in subpackages:
  + the xscreensaver subpackage contains xscreensaver itself
  + the xscreensaver-data subpackage contains a selection of nice
    screensavers that will be installed by default with
    xscreensaver, but also gnome-screensaver
  + the xscreensaver-data-extra subpackage contains the remaining
    screensavers.
- This implements fate#308474.
* Thu Dec 24 2009 coolo@novell.com
- update to version 5.10
  * new hacks: rubikblocks, surfaces
  * Retired hypercube and hyperball, which are redundant with polytopes.
  * Updates to mirrorblob, glhanoi, and sonar
* Fri Dec  4 2009 seife@opensuse.org
- de-fuzz the appdefaults patches
* Wed Jun  3 2009 sbrabec@suse.cz
- Strict aliasing fix.
* Tue Jun  2 2009 sbrabec@suse.cz
- Updated to version 5.08:
  * new hacks: sonar, jigsaw, photopile
  * Support for embedded orientation in the latest gdk-pixbuf
  * unlock timer improvements
  * minor fixes
- Prevent warnings in xscreensaver-getimage-file (bnc#408673).
* Tue Sep 30 2008 pgajdos@suse.cz
- fixed [bnc#368582]
  * fireworkx-man.patch
* Wed Sep  3 2008 sbrabec@suse.cz
- Updated to version 5.07:
  * Xinerama/RANDR fixes: this time for sure.  It should now work
    to add/remove monitors or resize screens at any time. Tweaks
    for old-style multi-screen.
  * Fixed the bouncing ball in `stairs'.
  * `flipflop' can load images onto the tiles.
  * Improved layout of the preferences dialogs: they should all now
    be usable even on ridiculously tiny laptop screens.
  * MacOS preferences text fields now prevent you from entering
    numbers that are out of range.
  * Added "Reset to Defaults" button on X11.
  * Added relevant Wikipedia links to many of the screen saver
    descriptions.
  * All hacks support the `-fps' option, not just GL ones.
  * The `-fps' option now shows CPU load.
  * Added bumpy skin and cel shading to `skytentacles'.
  * Added the missing Utah Teapotahedron to `polyhedra'.
  * `blitspin' works with color images on OSX now.
  * Added transparency to `stonerview'.
  * New hack, `skytentacles'.
  * New version of `gleidescope'.
  * Added the `-log' option to the xscreensaver daemon, since a
    truly shocking number of Linux users seem to have no idea how
    to redirect output to a file.
  * Added `-duration' arg to most image-loading hacks, so that they
    pick a new image every few minutes.
  * Added an ATM crash to BSOD.
* Wed Apr  2 2008 sbrabec@suse.cz
- Updated to version 5.05:
  * New hacks, `cubicgrid', `hypnowheel', and `lcdscrub' (which
    isn't really a screen saver).
  * Updates to `m6502' and `gears'.
  * Fixed double-buffering problems in `cubestorm' and `noof'.
  * Better handling of horizontal scroll wheels.
  * Attempt to work around latest Xinerama braindamage: if the
    server reports overlapping screens, use the largest
    non-overlapping rectangles available.
  * Don't warning about receipt of bogus ClientMessages, since
    Gnome's just never going to stop sending those.
  * The recent PAM changes broke the "Caps Lock" warning in the
    password dialog, the failed login warnings, and syslogging.
    Fixed all that.
* Fri Mar  7 2008 pcerny@suse.cz
- update of override_redirect patch (bnc#235715,bnc#365549)
* Mon Mar  3 2008 sbrabec@suse.cz
- Require /sbin/unix2_chkpwd from pam-modules (bnc#326304#c12).
* Tue Feb 19 2008 pcerny@suse.cz
- patch for detection of override_redirect windows (#235715)
* Fri Feb  1 2008 aj@suse.de
- Fix compile.
* Thu Jan 17 2008 sbrabec@suse.cz
- Disabled direct PAM use and shadow (both needs suid) (#326304).
- Enabled login manager.
* Mon Nov 19 2007 sbrabec@suse.cz
- Updated to version 5.04:
  * Fixed a possible crash in the unlock dialog
  * New hacks: moebiusgears, abstractile, and lockward.
  * Rewrote gears to use better (involute) gear models, and to be
    more random.
  * Minor updates: cwaves, voronoi, deco, glcells, rd-bomb,
    fireworkx and webcollage.
  * pong can now display the current time as the score.
  * xmatrix -mode pipe works better.
* Mon Sep 10 2007 sbrabec@suse.cz
- Set Categories properly and not show in KDE (#293688).
* Tue Aug  7 2007 sbrabec@suse.cz
- Updated to version 5.03:
  * New hacks, cwaves, glcells, m6502, and voronoi.
  * Minor fixes to bsod.
  * Fixed possible crash with PAM USB-dongle auth.
  * Updated webcollage to track recent Google Images and Flickr
    changes.
  * Reworked PAM code to support fingerprint readers, etc.
  * Fixed a Xinerama crash when changing the screen count.
  * New blobbier mirrorblob.
  * Minor updates to lisa, bsod, ifs, hypertorus, polytopes,
    circuit, endgame, crackberg, flipflop, flipscreen3d, fliptext,
    and carousel.
* Mon Apr 23 2007 pcerny@suse.cz
- enabled glslideshow - zombie DoS (#145173) is fixed in 5.01
* Mon Feb  5 2007 sbrabec@suse.cz
- Removed obsolete desktop files and fixed Categories (#242053).
* Wed Jan 17 2007 sbrabec@suse.cz
- GNOME prefix changed to /usr.
* Mon Oct 23 2006 sbrabec@suse.cz
- Updated to version 5.01:
  * Backed out recent locale-related changes, since they broke far
  more things than they fixed.
  * Fail gracefully with ridiculously small window sizes.
  * Better explosions in `boxed'.
  * More dynamic motion in `sproingies'.
  * More options in `flipflop'.
  * Minor updates to `topblock'.
  * Various other minor fixes.
* Wed Aug 30 2006 anosek@suse.cz
- updated to 5.00
  * All image-loading happens asynchronously.
  * xscreensaver-getimage-file caches the contents of the
    image directory for a few hours, so consecutive runs
    won't have to re-list the whole directory tree.
  * New hacks, `topblock' and `glschool'.
  * Removed `xteevee' (superceded by `xanalogtv').
  * Added variable-sized puzzle pieces to `jigsaw'.
  * Changes to the defaults and command-line options of
    many hacks to make the .xml files more consistent.
  * Reap zombies in `glslideshow' and `carousel'.
  * `xmatrix -mode pipe' displays the text of a subprocess.
  * `endgame' has higher resolution chess-piece models.
  * `webcollage' takes a -directory option to get images
    from a local directory.
  * New versions of `cube21', `glsnake', `celtic'.
  * Backed out a DPMS-related patch that cause desktop
    flickering with some X servers.
  * Fixed startup crash in getgroups() when running setuid.
  * Default to not displaying stderr on the saver window.
  * Fixed bad free() in "Documentation" button.
  * Don't try to run hacks that aren't installed.
  * Minor fixes to various XML config files and man pages.
- dropped obsolete patches (fix-configs, root-overflow,
  demo-overflow)
* Mon Aug  7 2006 sbrabec@suse.cz
- Worked around build problems with latest gettext.
- Changed paths for X.Org 7.
* Thu Apr 13 2006 sbrabec@suse.cz
- Use new control-center Categories instead of old ones.
* Fri Feb 17 2006 sbrabec@suse.cz
- Disabled glslideshow, which causes zombie DoS (#145173).
* Fri Feb 17 2006 coolo@suse.de
- fix another hack's config
* Wed Feb 15 2006 sbrabec@suse.cz
- Fixed xscreensaver-demo buffer overflow (#150338).
* Wed Feb  8 2006 sbrabec@suse.cz
- Fixed buffer overflow when started as root (#148713).
* Sat Feb  4 2006 aj@suse.de
- Cleanup BuildRequires.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 16 2006 dmueller@suse.de
- 4.23 update
* Thu Sep  8 2005 dmueller@suse.de
- fix commandline configs
* Mon Aug  1 2005 clahey@suse.de
- Check if we're 3d accelerated in glslideshow.
* Thu Jun 30 2005 sbrabec@suse.cz
- Updated to version 4.22.
- Build with gle.
- Fixed unlocking with empty password (#5854).
* Tue May 17 2005 mcihar@suse.cz
- fix undefined variable use
* Thu Apr 21 2005 mcihar@suse.cz
- fix documentation for xscreensaver-command -exit (bug #62810)
- do not echo stars for password (bug #8019)
- regenerate patches
* Mon Apr 11 2005 mcihar@suse.cz
- update to 4.21
- enabled gdmflexiserver support (bug #74328)
- do no use fortune as default source for text (bug #5856)
- drop fortune wrapper because of above
- cleanup patches, remove those making no real effect
* Sat Mar 19 2005 clahey@suse.de
- Updated patch to choose correct default screen saver.
* Thu Mar 17 2005 sbrabec@suse.cz
- Fixed capplets desktop files path (#73047).
- Removed gnome subpackage containing only capplet desktop file.
* Mon Mar 14 2005 clahey@suse.de
- Added a desktop file for gnomecc.
* Fri Feb 25 2005 mcihar@suse.cz
- update to 4.20 (bug #66527)
* Fri Dec 17 2004 mcihar@suse.cz
- update to 4.19
* Thu Dec 16 2004 hvogel@suse.de
- fix desktop file
- install 2 desktop files. one for xscreensaver, one for -gnome
- take control-center2 to nfb for icons
* Tue Nov 23 2004 ro@suse.de
- "sed -i" does not work on old distributions
* Mon Nov 15 2004 kukuk@suse.de
- Use common-* PAM config files
* Sun Nov  7 2004 ro@suse.de
- make it build
* Mon Nov  1 2004 mmj@suse.de
- locale rename no to nb
* Wed Oct 13 2004 mcihar@suse.cz
- require rather desktop-data than desktop-data-SuSE
* Fri Oct  1 2004 mcihar@suse.cz
- fix vroot brokeness (bug #46370)
* Thu Sep 23 2004 hhetter@suse.de
- change to /usr/share/wallpapers in XScreenSaver.ad.in too
  (#45892)
* Tue Sep 21 2004 mcihar@suse.cz
- use images from /usr/share/wallpapers and require desktop-data-SuSE for them (bug #43900)
* Tue Sep 21 2004 ro@suse.de
- remove requires for gnome-themes, pulls half of GNOME
* Mon Sep 20 2004 clahey@suse.de
- Remove 5 screensavers from hacklist that are known to crash
  proprietary NVidia X drivers.
- Require gnome-themes for background art.
* Wed Sep  8 2004 mcihar@suse.cz
- build with libjpeg to get jpeg support
* Mon Sep  6 2004 mcihar@suse.cz
- drop build dependancy on gnome stuff
- sync patches with NLD
* Fri Aug 20 2004 mcihar@suse.cz
- install locales to /usr/share
* Tue Aug 17 2004 mcihar@suse.cz
- update to 4.18
- replace some patches (webcollage removing and default hacklist
  modification) with sed expression to avoid regenerating patch on each
  release
* Tue Aug  3 2004 clahey@suse.de
- Don't show yellow text for missing screensaver executables (benkahn).
- Changed default screensaver (benkahn).
* Wed Jul 14 2004 mcihar@suse.cz
- moved hacks man pages to section 6, which is more appropriate. Also fixes
  file conflict with barcode.
- dropped not needed README.SuSE
* Tue Jul  6 2004 jody@suse.de
- Tweak the desktop file for gnome control-center2
* Thu Jul  1 2004 mcihar@suse.cz
- use %%{_libdir} for hacks installation
* Thu Jul  1 2004 mcihar@suse.cz
- moved from /usr/X11R6 to %%{_prefix}
* Mon Jun 28 2004 mcihar@suse.cz
- fixed penrose configuration (bug #42373)
* Fri Jun 18 2004 mcihar@suse.cz
- remove webcollage (bug 42196 - often downloading porn pictures)
* Wed May 19 2004 mcihar@suse.cz
- update to 4.16
* Mon Mar 29 2004 ro@suse.de
- automake no longer defined MKINSTALLDIRS
  use "mkdir -p" in po/Makefile.in.in
* Mon Mar  1 2004 mcihar@suse.cz
- update to 4.15
- removed obsoleted patches
- compile with -fno-strict-aliasing
* Wed Feb 25 2004 hhetter@suse.de
- added xscreensaver-hacklist.patch: change the default
  xscreenhack list
* Fri Jan 16 2004 kukuk@suse.de
- Add pam-devel to neededforbuild
* Fri Dec 12 2003 mcihar@suse.cz
- perl-XML-Parser added to neededforbuild as intltool requires it
* Fri Nov 21 2003 okir@suse.de
- xscreensaver would occasionally crash while validating
  passwords (#33192) or act in other unexpected ways (#30986)
* Wed Nov 19 2003 mcihar@suse.cz
- fix for unsecure /tmp handling (bug #32866)
* Wed Oct 29 2003 mcihar@suse.cz
- updated to 4.14:
  * New hacks, fontglide, apple2, xanalogtv, pong, gleidescope, mirrorblob, and blinkbox.
  * New version of glsnake (with many more models.)
  * Another Windows crash in bsod; also HVX/GCOS6/TPS6.
  * New version of endgame.
  * Various minor fixes.
- some our patches included in upstream
* Thu Oct 16 2003 mcihar@suse.cz
- do not use root for build
- disable fortune test in order to not modify root filesystem
  (disable-fortune-test.diff)
* Thu Oct  2 2003 mcihar@suse.cz
- updated to 4.13:
  * On Xinerama systems, xscreensaver now runs one hack on
    each monitor (just like in "real" multi-head mode)
    instead of running one hack stretching across all the
    screens.  Note that for this to work with any 3rd party
    screensavers, they must update their "vroot.h" file.
  * `webcollage' and `vidwhacker' display images using
    `xscreensaver-getimage' now.
  * Added `ljlatest' script for use with `starwars' and
    `phosphor'.
- rediffed some patches, removed obsollete patches
- move GNOME related stuff into separate package
* Thu Sep 18 2003 mcihar@suse.cz
- hide menu entry only for KDE/GNOME
* Wed Sep 17 2003 adrian@suse.de
- hide menu entry in KDE
* Mon Sep 15 2003 mcihar@suse.cz
- do not require control-center2 (bug #30810)
* Wed Aug 20 2003 mcihar@suse.cz
- updated to 4.12:
  * New GL hacks, `flipflop', `antspotlight', and `polytopes'.
  * Added VMS to `bsod'.
  * Updates to `webcollage' and `queens'.
  * Fixed a bug that could cause PAM to hang.
- the last mentioned change fixes our bug #29113
* Tue Aug 12 2003 pthomas@suse.de
- Add autoheader templates.
- Add intltool to #neededforbuild and use intltoolize.
- Use AM_GLIB_GNU_GETTEXT.
- Fix all cases of type-punning so that the compiler doesn't warn.
- Fix all int<->pointer casts.
- Fix translations.
* Thu Aug  7 2003 mcihar@suse.cz
- udate to 4.11
- don't require fortune, instead include wrapper that will print
  message, that user might want to install fortune package
* Wed Jul 30 2003 sf@suse.de
- fixed specfile for non-ix86 and alpha-architectures
* Wed Jul 16 2003 sbrabec@suse.cz
- Turned on GNOME2 interface instead of GTK1.
- Packaged GNOME related files.
* Fri Jun 13 2003 kukuk@suse.de
- Store locale data below /usr/X11R6/share/locale like every other
  application is doing, too.
* Tue May 27 2003 mcihar@suse.cz
- cleanup $RPM_BUILD_ROOT
* Wed Apr  9 2003 mcihar@suse.cz
- requires fortune (fixes #25194)
- reenabled webcollage and vidwhacker
- updated to 4.09:
  * New hacks, `flyingtoasters', `bouncingcow', `jigglypuff',
    `glslideshow', `atunnels' and `piecewise'.
  * More models in `engine'.
  * Physics improvement in `fluidballs'.
  * Rewrote `xscreensaver-getimage' to remove reliance on
    external image loaders (xv, chbg, xloadimage, etc.)
    and to reduce flicker when loading files.
  * Made `gflux' and `flipscreen3d' be mouse-spinnable.
  * Added -clock option to `barcode'.
  * Minor fixes to `endgame', `flurry', `flipscreen3d',
    and `gflux'.
* Fri Feb  7 2003 kukuk@suse.de
- Use pam_unix2.so instead of pam_unix.so
* Tue Feb  4 2003 pmladek@suse.cz
- updated to version 4.07:
  * new hacks - flurry, eruption, popsquares, barcode
  * updated hacks - maze, sproingies, fluidballs, whirlygig
  * fixes for running xscreensaver to a remote XFree86 display
  * fixed Perl version-sensitivity in xscreensaver-getimage-file
  * fixed GTK2 scrolling bug in xscreensaver-demo
* Tue Nov 19 2002 pmladek@suse.cz
- updated to version 4.06:
  * new hacks -  glblur, halftone
  * updated hacks - endgame, queens, bumps, glplanet, engine, circuit,
    menger, molecule, bsod
  * fixed bugs in hacks - critical, webcollage, distort, bsod
  * fixed a bug that could rarely cause GL hacks to fail to double-buffer
  * fixed a bug that caused the window manager close box to kill
    `xscreensaver-demo' with a crash instead of a graceful exit
  * fixed a bug that caused `xscreensaver-gl-helper' to print a nonsense
    visual ID with some versions of `printf'
- removed obsolete patch which fixes default doc viewer
- installed correctly into the /usr/X11R6 tree
* Tue Aug 27 2002 pmladek@suse.cz
- inverted expression in DEFAULT section of function get_pixel_resource,
  so, the background will be white when the requested color can not be
  allocated [#17520, #17525]
* Mon Aug 26 2002 pmladek@suse.cz
- pam module is accessed via new helper utility unix2_chkpw and xscreensaver
  binary do not need group id bit now, many thanks to Olaf Kirch <okir@suse.de>
  for hint and patch [#18132]
- fixed to build configure from configure.in
* Mon Aug 19 2002 pmladek@suse.cz
- installed icons are correctly [#17521]
- installed locale files correctly
- mozilla is the default doc viewer instead of netscape now
* Tue Aug 13 2002 ro@suse.de
- remove gnome subpackage
- remove all related packages from neededforbuild
- xf86 used in neededforbuild for bitmaps
* Fri Jul  5 2002 kukuk@suse.de
- Use %%ix86 macro
* Wed Jul  3 2002 coolo@suse.de
- updated to 4.05
- removed kde2 screensaver hack
* Thu Mar 21 2002 ro@suse.de
- add subpackage -gnome containing a xscreensaver-demo-gnome
  with full capplet support (needed for screensaver configuration
  in gnome) (#14265)
* Mon Jan 21 2002 cihlar@suse.cz
- updated to version 4.00:
  * Redesigned `xscreensaver-demo' GUI
  * bugfixes
* Fri Dec  7 2001 cihlar@suse.cz
- updated to version 3.34:
  * memory limit is off by default
  * several fixes
  * added several new screensavers
- removed obsolete patches
- fixed README.SuSE
* Thu Nov  8 2001 ro@suse.de
- use mesa-devel-packages in neededforbuild
* Thu Oct  4 2001 cihlar@suse.cz
- increased memoryLimit to 500M [#11468]
* Fri Aug 24 2001 ro@suse.de
- removed /lib/security path from pam.d config file
* Mon Jul 30 2001 cihlar@suse.cz
- update to version 3.33
* Thu Jul 19 2001 cihlar@suse.cz
- fixed to compile on axp
* Mon Jun 18 2001 cihlar@suse.cz
- moved xscreensaver.kss to /opt/kde2/bin
* Tue Jun 12 2001 cihlar@suse.cz
- fixed to compile with new autoconf
* Mon Jun  4 2001 cihlar@suse.cz
- fixed arguments to XtVa... functions for ia64 [bug #8612]
* Mon May 21 2001 cihlar@suse.cz
- fixed cast warnings on ia64
- fixed includes
* Tue Apr 10 2001 cihlar@suse.cz
- updated to version 3.31
* Thu Mar 15 2001 ro@suse.de
- changed neededforbuild <mesaglu> to <xf86glu>
- changed neededforbuild <mesaglu-devel> to <xf86glu-devel>
* Tue Mar 13 2001 cihlar@suse.cz
- update to version 3.29
* Thu Mar  8 2001 uli@suse.de
- added mesaglut* to neededforbuild
* Wed Mar  7 2001 ro@suse.de
- changed neededforbuild <mesadev> to <mesa-devel>
* Fri Dec 15 2000 grimmer@suse.de
- added GLE support for Intel archs
* Wed Nov 22 2000 cihlar@suse.cz
- renamed xscrns -> xscreensaver
- update to version 3.26
- bzipped sources
- removed xpm.h from sources
- compile again with xdevel
- fixed copyright
* Mon Nov 20 2000 ro@suse.de
- switch to openmotif
* Tue Sep  5 2000 schwab@suse.de
- Don't add -Wp,-lang-c89 to $CC, enables strict ANSI mode in newer gcc
  versions.
* Tue Aug 22 2000 cihlar@suse.cz
- change /usr/X11R6/xscreensaver to 2755 root.shadow
* Wed Aug  2 2000 cihlar@suse.cz
- compile with xpm support
* Fri Jul 28 2000 cihlar@suse.cz
- compile with xdevel3 instead of xdevel
* Wed Jul 12 2000 cihlar@suse.cz
- mesadev added to needforbuild
* Mon Jul  3 2000 cihlar@suse.cz
- screensaver webcollage removed
* Thu Apr 13 2000 cihlar@suse.cz
- added define kdedir to spec file
* Wed Apr 12 2000 cihlar@suse.cz
- upgrade to version 3.24
- added BuildRoot
- clean up spec file
* Wed Jan 26 2000 ro@suse.de
- update to 3.22
- move demos to /usr/X11R6/lib/xscreensaver
- use lesstif
  (xscreensaver-demo won't build without either motif or gtk)
* Thu Nov  4 1999 ro@suse.de
- update to 3.18
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Thu Jul  1 1999 grimmer@suse.de
- Update to 3.16, added new manual pages
- added README.SuSE and screenblank.txt to DOCDIR
* Tue Jun 15 1999 kukuk@suse.de
- Don't link mesa static, enable PAM support
* Mon Jun 14 1999 ro@suse.de
- added mesasoft to neededforbuild
* Wed Apr 14 1999 ro@suse.de
- update to 3.09
- link static against mesa libs
* Tue Feb 10 1998 bs@suse.de
- fixed Check for man pages
* Tue Jan 13 1998 bb@suse.de
  Changes since 2.13:
- Better fix for the Motif drag-and-die lossage.
- Put in some kludges to work around a LessTif bug.
- XScreenSaver is known to work with LessTif 0.82 now.
- Made fading work on high-end SGI video hardware.
- Fixed another SGI-specific bug in screen grabbing;
  will the madness never cease?
- Fixed another crash in `xlyap'.
